pub struct BlobCache<B, H, S, T>where
B: BlobStoreGet<H>,
H: HashProtocol,
S: BlobSchema + 'static,
T: TryFromBlob<S>,
Handle<H, S>: ValueSchema,{ /* private fields */ }Expand description
Re-export of the blob cache wrapper. Lazy cache for blob conversions keyed by blob handle.
Implementations
Sourceimpl<B, H, S, T> BlobCache<B, H, S, T>where
B: BlobStoreGet<H>,
H: HashProtocol,
S: BlobSchema + 'static,
T: TryFromBlob<S>,
Handle<H, S>: ValueSchema,
impl<B, H, S, T> BlobCache<B, H, S, T>where
B: BlobStoreGet<H>,
H: HashProtocol,
S: BlobSchema + 'static,
T: TryFromBlob<S>,
Handle<H, S>: ValueSchema,
Sourcepub fn with_capacity(blobs: B, capacity: usize) -> Self
pub fn with_capacity(blobs: B, capacity: usize) -> Self
Creates a new cache backed by blobs with the given entry capacity.