MemoryBlobStore

Struct MemoryBlobStore 

pub struct MemoryBlobStore<H: HashProtocol> { /* private fields */ }
Re-export of the in-memory blob store. A mapping from Handles to Blobs.

Implementations

Source

impl<H: HashProtocol> MemoryBlobStore<H>

pub fn new() -> MemoryBlobStore<H>

Creates a new MemoryBlobStore with no blobs.

The store keeps all data in memory and is primarily intended for tests or other transient repositories such as workspaces.

pub fn insert<S>(&mut self, blob: Blob<S>) -> Value<Handle<H, S>>
where S: BlobSchema,

Inserts blob into the store and returns the newly computed handle.

The handle is derived from hashing the blob’s bytes using the hash protocol associated with this store.

pub fn keep<I>(&mut self, handles: I)
where I: IntoIterator<Item = Value<Handle<H, UnknownBlob>>>,

Drops any blobs that are not referenced by one of the provided tribles.

This is a simple mark-and-sweep style GC used to prune unreferenced blobs from long lived stores.