Module examples

Module examples 

Example namespaces and sample datasets for documentation and tests. This module contains an example namespace for use in the documentation. It is not intended to be used in practice.

Modules

literature
Example attribute namespace modelling literary works and their authors.

Functions

dataset
Returns a small sample dataset used in the documentation.