ExclusiveId

Struct ExclusiveId 

#[repr(transparent)]
pub struct ExclusiveId { pub id: Id, /* private fields */ }
Represents an ID that can only be used by a single writer at a time.

ExclusiveIds are associated with one owning context (typically a thread) at a time. Because they are Send and !Sync, they can be passed between contexts, but not used concurrently. This makes use of Rust’s borrow checker to enforce a weaker form of software transactional memory (STM) without rollbacks - as these are not an issue with the heavy use of copy-on-write data structures.

They are automatically associated with the thread they are dropped from, which can be used in queries via the local_ids constraint. You can also make use of explicit IdOwner containers to store them when not actively used in a transaction.

Most methods defined on ExclusiveId are low-level primitives meant to be used for the implementation of new ownership management strategies, such as a transactional database that tracks checked out IDs for ownership, or distributed ledgers like blockchains.

Fields

id: Id

The underlying identifier.

Implementations

Source

impl ExclusiveId

pub fn force(id: Id) -> Self

Forces a regular (read-only) Id to become a writable ExclusiveId.

This is a low-level primitive that is meant to be used for the implementation of new ownership management strategies, such as a transactional database that tracks checked out IDs for ownership, or distributed ledgers like blockchains.

This should be done with care, as it allows scenarios where multiple writers can create conflicting information for the same ID. Similar caution should be applied when using the force_ref and forget methods.

Arguments
pub fn force_ref(id: &Id) -> &Self

Safely transmutes a reference to an Id into a reference to an ExclusiveId.

Similar caution should be applied when using the force method.

Arguments
  • id - A reference to the Id to be transmuted.
pub fn release(self) -> Id

Releases the ExclusiveId, returning the underlying Id.

Returns

The underlying Id.

pub fn forget(self) -> Id

Forgets the ExclusiveId, leaking ownership of the underlying Id, while returning it.

This is not as potentially problematic as force, because it prevents further writes with the ExclusiveId, thus avoiding potential conflicts.

Returns

The underlying Id.

Methods from Deref<Target = Id>

pub fn aquire(&self) -> Option<ExclusiveId>

Takes ownership of this Id from the current write context (i.e. thread). Returns None if this Id was not found, because it is not associated with this write context, or because it is currently aquired.