OwnedId

Struct OwnedId 

pub struct OwnedId<'a> {
    pub id: Id,
    /* private fields */
}
An ExclusiveId that is associated with an IdOwner. It is automatically returned to the IdOwner when dropped.

Fields

id: Id

The underlying identifier.

Methods from Deref<Target = Id>

pub fn aquire(&self) -> Option<ExclusiveId>

Takes ownership of this Id from the current write context (i.e. thread). Returns None if this Id was not found, because it is not associated with this write context, or because it is currently aquired.