pub enum JsonImportError {
PrimitiveRoot,
EncodeString {
field: String,
source: EncodeError,
},
EncodeNumber {
field: String,
source: EncodeError,
},
Syntax(String),
}Expand description
Error returned by JsonObjectImporter when importing a JSON document.
Variants
PrimitiveRoot
The document root is a primitive (string, number, bool, null) — only objects and arrays of objects are accepted.
EncodeString
A string field could not be encoded into the target value schema.
EncodeNumber
A number field could not be encoded into the target value schema.
Syntax(String)
The JSON input is syntactically invalid.