pub struct View<T>{ /* private fields */ }Expand description
Immutable view with zero-copy field derive and cloning.
Access itself is the same as accessing a &T.
Has a backing ByteOwner that retains the bytes until all views are dropped,
analogue to Bytes.
See ByteOwner for an exhaustive list and more details.
Implementations
Sourceimpl<T> View<T>
impl<T> View<T>
Sourcepub unsafe fn from_raw_parts(
data: &'static T,
owner: Arc<dyn ByteOwner>,
) -> View<T>
pub unsafe fn from_raw_parts( data: &'static T, owner: Arc<dyn ByteOwner>, ) -> View<T>
Creates a view from raw parts without any checks.
Safety
The caller must guarantee that data remains valid for the lifetime of
owner.
Sourcepub fn downcast_to_owner<O>(self) -> Result<Arc<O>, View<T>>
pub fn downcast_to_owner<O>(self) -> Result<Arc<O>, View<T>>
Returns the owner of the View in an Arc.
Sourceimpl<T> View<T>
impl<T> View<T>
Sourcepub fn field_to_view<F>(&self, field: &F) -> Option<View<F>>
pub fn field_to_view<F>(&self, field: &F) -> Option<View<F>>
Attempt to convert reference to a zero-copy subview of this View.
Returns None if the bytes of the child are outside the memory range of
the bytes of this view.
This is similar to Bytes::slice_to_bytes but for View.