Variable

Struct Variable 

pub struct Variable<T: ValueSchema> {
    pub index: VariableId,
    /* private fields */
}
A placeholder for unknowns in a query. Within the query engine each variable is identified by an integer, which can be accessed via the index property. Variables also have an associated type which is used to parse the Values found by the query engine.

Fields

index: VariableId

The integer index identifying this variable in the Binding.

Implementations

Source

impl<T: ValueSchema> Variable<T>

pub fn new(index: VariableId) -> Self

Creates a variable with the given index.

pub fn extract(self, binding: &Binding) -> &Value<T>

Extracts the bound value for this variable from binding.

Panics

Panics if the variable has not been bound.

Source

impl<T: ValueSchema> Variable<T>

pub fn is(self, constant: Value<T>) -> ConstantConstraint

Create a constraint so that only a specific value can be assigned to the variable.