pub enum BuildError {
ParseParentSig(UnarchiveError),
ParentSigShape,
}Expand description
Errors returned by build_capability.
Variants
ParseParentSig(UnarchiveError)
The provided parent signature blob could not be parsed as a valid SimpleArchive.
ParentSigShape
The provided parent signature blob did not contain exactly one
signature entity (i.e. exactly one entity carrying sig_signs).