pub enum CreateCommitError<BlobErr: Error + Debug + Send + Sync + 'static> {
ContentStorageError(BlobErr),
CommitStorageError(BlobErr),
}Expand description
An error that can occur when creating a commit. This error can be caused by a failure to store the content or metadata blobs.
Variants
ContentStorageError(BlobErr)
Failed to store the content blob.
CommitStorageError(BlobErr)
Failed to store the commit metadata blob.