PushError

Enum PushError 

pub enum PushError<Storage: BranchStore<Blake3> + BlobStore<Blake3>> {
    StorageBranches(Storage::BranchesError),
    StorageReader(<Storage as BlobStore<Blake3>>::ReaderError),
    StorageGet(<<Storage as BlobStore<Blake3>>::Reader as BlobStoreGet<Blake3>>::GetError<UnarchiveError>),
    StoragePut(<Storage as BlobStorePut<Blake3>>::PutError),
    BranchUpdate(Storage::UpdateError),
    BadBranchMetadata(),
    MergeError(MergeError),
}
Error returned by Repository::push and Repository::try_push.

Variants



StorageBranches(Storage::BranchesError)

An error occurred while enumerating the branch storage branches.



StorageReader(<Storage as BlobStore<Blake3>>::ReaderError)

An error occurred while creating a blob reader.



StorageGet(<<Storage as BlobStore<Blake3>>::Reader as BlobStoreGet<Blake3>>::GetError<UnarchiveError>)

An error occurred while reading metadata blobs.



StoragePut(<Storage as BlobStorePut<Blake3>>::PutError)

An error occurred while transferring blobs to the repository.



BranchUpdate(Storage::UpdateError)

An error occurred while updating the branch storage.



BadBranchMetadata()

Malformed branch metadata.



MergeError(MergeError)

Merge failed while retrying a push.