pub enum HashError {
BadProtocol,
BadHex(FromHexError),
}Expand description
An error that can occur when converting a hash value from a string. The error can be caused by a bad protocol or a bad hex encoding.
Variants
BadProtocol
The string does not start with the expected protocol prefix
(e.g. "blake3:").
BadHex(FromHexError)
The hex portion could not be decoded.