pub enum FromStrError {
TooLong,
InteriorNul,
}Expand description
An error that occurs when converting a string to a short string. This error occurs when the string is too long or contains an interior NUL byte.
Variants
TooLong
The string exceeds 32 bytes when encoded as UTF-8.
InteriorNul
The string contains a NUL byte, which is used as the terminator.