Value

Struct Value 

#[repr(transparent)]
pub struct Value<T: ValueSchema> { pub raw: RawValue, /* private fields */ }
A value is a 32-byte array that can be (de)serialized as a Rust type. The schema type parameter is an abstract type that represents the meaning and valid bit patterns of the bytes.

Example

use triblespace_core::prelude::*;
use valueschemas::R256;
use num_rational::Ratio;

let ratio = Ratio::new(1, 2);
let value: Value<R256> = R256::value_from(ratio);
let ratio2: Ratio<i128> = value.try_from_value().unwrap();
assert_eq!(ratio, ratio2);

Fields

raw: RawValue

The 32-byte representation of this value.

Implementations

Source

impl<S: ValueSchema> Value<S>

pub fn new(value: RawValue) -> Self

Create a new value from a 32-byte array.

Example
use triblespace_core::value::{Value, ValueSchema};
use triblespace_core::value::schemas::UnknownValue;

let bytes = [0; 32];
let value = Value::<UnknownValue>::new(bytes);
pub fn validate(self) -> Result<Self, S::ValidationError>

Validate this value using its schema.

pub fn is_valid(&self) -> bool

Check if this value conforms to its schema.

pub fn transmute<O>(self) -> Value<O>
where O: ValueSchema,

Transmute a value from one schema type to another. This is a safe operation, as the bytes are not changed. The schema type is only changed in the type system. This is a zero-cost operation. This is useful when you have a value with an abstract schema type, but you know the concrete schema type.

pub fn as_transmute<O>(&self) -> &Value<O>
where O: ValueSchema,

Transmute a value reference from one schema type to another. This is a safe operation, as the bytes are not changed. The schema type is only changed in the type system. This is a zero-cost operation. This is useful when you have a value reference with an abstract schema type, but you know the concrete schema type.

pub fn as_transmute_raw(value: &RawValue) -> &Self

Transmute a raw value reference to a value reference.

Example
use triblespace_core::value::{Value, ValueSchema};
use triblespace_core::value::schemas::UnknownValue;
use std::borrow::Borrow;

let bytes = [0; 32];
let value: Value<UnknownValue> = Value::new(bytes);
let value_ref: &Value<UnknownValue> = &value;
let raw_value_ref: &[u8; 32] = value_ref.borrow();
let value_ref2: &Value<UnknownValue> = Value::as_transmute_raw(raw_value_ref);
assert_eq!(&value, value_ref2);
pub fn from_value<'a, T>(&'a self) -> T
where T: TryFromValue<'a, S, Error = Infallible>,

Deserialize a value with an abstract schema type to a concrete Rust type.

This method only works for infallible conversions (where Error = Infallible). For fallible conversions, use the Value::try_from_value method.

Example
use triblespace_core::prelude::*;
use valueschemas::F64;

let value: Value<F64> = (3.14f64).to_value();
let concrete: f64 = value.from_value();
pub fn try_from_value<'a, T>( &'a self, ) -> Result<T, <T as TryFromValue<'a, S>>::Error>
where T: TryFromValue<'a, S>,

Deserialize a value with an abstract schema type to a concrete Rust type.

This method returns an error if the conversion is not possible. This might happen if the bytes are not valid for the schema type or if the rust type can’t represent the specific value of the schema type, e.g. if the schema type is a fractional number and the rust type is an integer.

For infallible conversions, use the Value::from_value method.

Example
use triblespace_core::prelude::*;
use valueschemas::R256;
use num_rational::Ratio;

let value: Value<R256> = R256::value_from(Ratio::new(1, 2));
let concrete: Result<Ratio<i128>, _> = value.try_from_value();