pub struct MemoryBlobStore<H: HashProtocol> { /* private fields */ }Implementations
Sourceimpl<H: HashProtocol> MemoryBlobStore<H>
impl<H: HashProtocol> MemoryBlobStore<H>
Sourcepub fn new() -> MemoryBlobStore<H>
pub fn new() -> MemoryBlobStore<H>
Creates a new MemoryBlobStore with no blobs.
The store keeps all data in memory and is primarily intended for tests or other transient repositories such as workspaces.
Sourcepub fn insert<S>(&mut self, blob: Blob<S>) -> Value<Handle<H, S>>where
S: BlobSchema,
pub fn insert<S>(&mut self, blob: Blob<S>) -> Value<Handle<H, S>>where
S: BlobSchema,
Inserts blob into the store and returns the newly computed handle.
The handle is derived from hashing the blob’s bytes using the hash protocol associated with this store.