pub struct Id { /* private fields */ }Expand description
Represents a unique abstract 128 bit identifier.
As we do not allow for all zero nil IDs,
Option<Id> benefits from Option nieche optimizations.
Note that it has an alignment of 1, and can be referenced as a [u8; 16] RawId.
Implementations
Sourceimpl Id
impl Id
Sourcepub fn from_hex(hex: &str) -> Option<Self>
pub fn from_hex(hex: &str) -> Option<Self>
Parses a hexadecimal identifier string into an Id.
Returns None if the input is not valid hexadecimal or represents the
nil identifier (all zero bytes).
Sourcepub fn as_transmute_raw(id: &RawId) -> Option<&Self>
pub fn as_transmute_raw(id: &RawId) -> Option<&Self>
Sourcepub fn aquire(&self) -> Option<ExclusiveId>
pub fn aquire(&self) -> Option<ExclusiveId>
Takes ownership of this Id from the current write context (i.e. thread).
Returns None if this Id was not found, because it is not associated with this
write context, or because it is currently aquired.