pub unsafe trait ByteEntry {
// Required method
fn key(&self) -> u8;
}Expand description
Types must implement this trait in order to be storable in the byte table.
Safety
Implementors must ensure that key() returns None iff the memory of the
type is mem::zeroed(). Failure to uphold this contract may lead to
incorrect behavior when entries are inserted into the table.