pub struct Variable<T: ValueSchema> {
pub index: VariableId,
/* private fields */
}Expand description
A placeholder for unknowns in a query.
Within the query engine each variable is identified by an integer,
which can be accessed via the index property.
Variables also have an associated type which is used to parse the Values
found by the query engine.
Fields
index: VariableIdThe integer index identifying this variable in the Binding.
Implementations
Sourceimpl<T: ValueSchema> Variable<T>
impl<T: ValueSchema> Variable<T>
Sourceimpl<T: ValueSchema> Variable<T>
impl<T: ValueSchema> Variable<T>
Sourcepub fn is(self, constant: Value<T>) -> ConstantConstraint
pub fn is(self, constant: Value<T>) -> ConstantConstraint
Create a constraint so that only a specific value can be assigned to the variable.