pub struct VariableContext {
pub next_index: VariableId,
}Expand description
Context for creating variables in a query. The context keeps track of the next index to assign to a variable. This allows for the creation of new anonymous variables in higher-level query languages.
Fields
next_index: VariableIdThe index that will be assigned to the next variable.
Implementations
Sourceimpl VariableContext
impl VariableContext
Sourcepub fn next_variable<T: ValueSchema>(&mut self) -> Variable<T>
pub fn next_variable<T: ValueSchema>(&mut self) -> Variable<T>
Create a new variable. The variable is assigned the next available index.
Panics if the number of variables exceeds 128.
This method is usually not called directly, but rather through typed query language macros like find!.