VariableSet

Struct VariableSet 

pub struct VariableSet { /* private fields */ }
Re-export of VariableSet. A fixed size bitset for up to 128 variables. The set is represented as a 128-bit integer where each bit represents the presence of the corresponding element in the set.

Implementations

Source

impl VariableSet

pub const fn new_empty() -> Self

Create a new empty set.

pub const fn new_full() -> Self

Create a new set with every value of the domain set.

pub fn new_singleton(index: usize) -> Self

Create a new set with a single value from the domain set.

pub fn is_empty(&self) -> bool

Check if the set is empty.

pub fn count(&self) -> usize

Count the number of elements in the set.

pub fn set(&mut self, index: usize)

Set the given value in the set.

pub fn unset(&mut self, index: usize)

Remove the given value from the set.

pub fn set_value(&mut self, index: usize, value: bool)

Sets or removes the given element into or from the set depending on the passed value.

pub fn set_all(&mut self)

Include every value in the domain in the set.

pub fn unset_all(&mut self)

Remove all values from the set.

pub fn is_set(&self, index: usize) -> bool

Check if the given value is in the set.

pub fn find_first_set(&self) -> Option<usize>

Finds the index of the first set bit. If no bits are set, returns None.

pub fn find_last_set(&self) -> Option<usize>

Finds the index of the last set bit. If no bits are set, returns None.

pub fn drain_next_ascending(&mut self) -> Option<usize>

Returns the index of the next set bit in the bit set, in ascending order, while unseting it.

pub fn drain_next_descending(&mut self) -> Option<usize>

Returns the index of the next set bit in the bit set, in descending order, while unseting it.

pub fn is_superset_of(&self, other: &Self) -> bool

Checks if the set is a superset of the passed set.

pub fn is_subset_of(&self, other: &Self) -> bool

Checks if the set is a subset of the passed set.

pub fn intersect(self, other: Self) -> Self

Compute the set intersection between the two given sets.

pub fn union(self, other: Self) -> Self

Compute the set union between the two given sets.

pub fn subtract(self, other: Self) -> Self

Compute the set subtraction between the two given sets.

pub fn difference(self, other: Self) -> Self

Compute the set difference between the two given sets.

pub fn complement(self) -> Self

Compute a set complement, removing every element that was in the set and inserting every element from the domain that wasn’t in the set.

pub fn keep_single(&mut self, index: usize)

Remove all elements from the set except the one passed. Equal to an intersection with a set containing only the passed element.

pub fn keep_range(&mut self, from_index: usize, to_index: usize)

Similar to keep_single, except that only values in the specified range are kept. Both range ends are inclusive.