pub fn commit_metadata(
signing_key: &SigningKey,
parents: impl IntoIterator<Item = Value<Handle<Blake3, SimpleArchive>>>,
msg: Option<Value<Handle<Blake3, LongString>>>,
content: Option<Blob<SimpleArchive>>,
metadata: Option<Value<Handle<Blake3, SimpleArchive>>>,
) -> TribleSetExpand description
Constructs commit metadata describing content, optional metadata, and its parent commits.
The resulting TribleSet is signed using signing_key so that its
authenticity can later be verified. If msg is provided it is stored as a
long commit message via a LongString blob handle. If metadata is provided
it is stored as a SimpleArchive handle.