pub enum PushError<Storage: PinStore + BlobStore> {
StorageBranches(Storage::PinsError),
StorageReader(<Storage as BlobStore>::ReaderError),
StorageGet(<<Storage as BlobStore>::Reader as BlobStoreGet>::GetError<UnarchiveError>),
StoragePut(<Storage as BlobStorePut>::PutError),
BranchUpdate(Storage::UpdateError),
BadBranchMetadata(),
MergeError(MergeError),
}Variants
StorageBranches(Storage::PinsError)
An error occurred while enumerating the branch storage branches.
StorageReader(<Storage as BlobStore>::ReaderError)
An error occurred while creating a blob reader.
StorageGet(<<Storage as BlobStore>::Reader as BlobStoreGet>::GetError<UnarchiveError>)
An error occurred while reading metadata blobs.
StoragePut(<Storage as BlobStorePut>::PutError)
An error occurred while transferring blobs to the repository.
BranchUpdate(Storage::UpdateError)
An error occurred while updating the branch storage.
BadBranchMetadata()
Malformed branch metadata.
MergeError(MergeError)
Merge failed while retrying a push.