ObjectStoreRemote

Struct ObjectStoreRemote 

pub struct ObjectStoreRemote { /* private fields */ }
Repository backed by an object_store compatible storage backend.

All data is stored in an external service (e.g. S3, local filesystem) via the object_store crate.

Implementations

Source

impl ObjectStoreRemote

pub fn with_url(url: &Url) -> Result<ObjectStoreRemote, Error>

Creates a repository pointing at the object store described by url.