pub struct TribleSet {
pub eav: PATCH<TRIBLE_LEN, EAVOrder, ()>,
pub vea: PATCH<TRIBLE_LEN, VEAOrder, ()>,
pub ave: PATCH<TRIBLE_LEN, AVEOrder, ()>,
pub vae: PATCH<TRIBLE_LEN, VAEOrder, ()>,
pub eva: PATCH<TRIBLE_LEN, EVAOrder, ()>,
pub aev: PATCH<TRIBLE_LEN, AEVOrder, ()>,
}Expand description
A collection of Tribles.
A TribleSet is a collection of Tribles that can be queried and manipulated. It supports efficient set operations like union, intersection, and difference.
The stored Tribles are indexed by the six possible orderings of their fields in corresponding PATCHes.
Clone is extremely cheap and can be used to create a snapshot of the current state of the TribleSet.
Note that the TribleSet does not support an explicit delete/remove operation,
as this would conflict with the CRDT semantics of the TribleSet and CALM principles as a whole.
It does allow for set subtraction, but that operation is meant to compute the difference between two sets
and not to remove elements from the set. A subtle but important distinction.
Fields
eav: PATCH<TRIBLE_LEN, EAVOrder, ()>vea: PATCH<TRIBLE_LEN, VEAOrder, ()>ave: PATCH<TRIBLE_LEN, AVEOrder, ()>vae: PATCH<TRIBLE_LEN, VAEOrder, ()>eva: PATCH<TRIBLE_LEN, EVAOrder, ()>aev: PATCH<TRIBLE_LEN, AEVOrder, ()>Implementations
Sourceimpl TribleSet
impl TribleSet
pub fn intersect(&self, other: &Self) -> Self
pub fn difference(&self, other: &Self) -> Self
pub fn new() -> TribleSet
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn fingerprint(&self) -> TribleSetFingerprint
pub fn fingerprint(&self) -> TribleSetFingerprint
Returns a fast fingerprint suitable for in-memory caching.
The fingerprint matches TribleSet equality, but it is not stable
across process boundaries because PATCH uses a per-process hash key.
pub fn insert(&mut self, trible: &Trible)
pub fn contains(&self, trible: &Trible) -> bool
pub fn iter(&self) -> TribleSetIterator<'_>